Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
// The first path in $GOPATH
GoPath []string
// The go package where .pb.go files protoc-gen-go creates will be written
PBPackage string
PBPath string
// The go package where the service code will be written
ServicePackage string
ServicePath string
// The paths to each of the .proto files truss is being run against
DefPaths []string
// The files of a previously generated service, may be nil
PrevGen map[string]io.Reader
}
Config defines the inputs to a truss service generation
Directories
¶
| Path | Synopsis |
|---|---|
|
Package execprotoc provides an interface for interacting with proto requiring only paths to files on disk
|
Package execprotoc provides an interface for interacting with proto requiring only paths to files on disk |
|
Package parsesvcname will parse the service name of a protobuf package.
|
Package parsesvcname will parse the service name of a protobuf package. |
Click to show internal directories.
Click to hide internal directories.